package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Aug 28, 2023
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Change is a change to a field
DiffSet returns the difference between two slice-based sets
DiffString returns the difference between two strings
type Diff[T any] struct {
Item T
Changes []Change
}
Diff is the difference between two items
Source Files
¶
Click to show internal directories.
Click to hide internal directories.