Documentation
¶
Index ¶
- func DiffIssues(old, head map[int]Issue) map[int]diff.Diff[Issue]
- func ParseIssueComments(jsonBytes []byte) (map[int][]IssueComment, error)
- func ParseIssues(jsonBytes []byte) (map[int]Issue, error)
- func ParsePullRequestReviews(jsonBytes []byte) (map[int][]PullRequestReview, error)
- type Account
- type Client
- func (c *Client) IssueComments(ctx context.Context, org, repo string, number int) ([]byte, error)
- func (c *Client) PullRequestReviews(ctx context.Context, org, repo string, number int) ([]byte, error)
- func (c *Client) Snapshot(ctx context.Context, org, repo string, opts SnapshotOptions) ([]byte, int, error)
- type Issue
- type IssueComment
- type Label
- type Milestone
- type PullRequest
- type PullRequestReview
- type SnapshotOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DiffIssues ¶
DiffIssues returns the difference between two sets of issues.
func ParseIssueComments ¶ added in v0.3.0
func ParseIssueComments(jsonBytes []byte) (map[int][]IssueComment, error)
func ParsePullRequestReviews ¶
func ParsePullRequestReviews(jsonBytes []byte) (map[int][]PullRequestReview, error)
Types ¶
type Client ¶
type Client struct {
Client *http.Client
APIVersion string
Token string
PageEvent func(page int) // PageEvent is called when a new page is being fetched.
}
func (*Client) IssueComments ¶ added in v0.3.0
IssueComments takes a snapshot of all comments for an issue.
type Issue ¶
type Issue struct {
HTMLURL string `json:"html_url"`
Number int `json:"number"`
Title string `json:"title"`
User Account `json:"user"`
Labels []Label `json:"labels"`
Assignees []Account `json:"assignees"`
State string `json:"state"`
Milestone Milestone `json:"milestone"`
CreatedAt time.Time `json:"created_at"`
ClosedAt *time.Time `json:"closed_at"`
PullRequest *PullRequest `json:"pull_request,omitempty"`
}
Issue is an abbreviated version of the GitHub issue type.
func (Issue) IsPullRequest ¶
type IssueComment ¶ added in v0.3.0
type PullRequest ¶
type PullRequestReview ¶
type SnapshotOptions ¶ added in v0.3.0
SnapshotOptions are options for taking a snapshot.
Click to show internal directories.
Click to hide internal directories.